pub struct PacManagerAction {
pub pacmanager_command: PacManagerCommand,
pub internal_config: InternalConfig,
pub non_interactive: bool,
pub custom_flags: Option<Vec<String>>,
}Expand description
An action of the package manager - the command to execute, custom flags, etc. This is passed to the ‘execute_action’ function.
Fields
pacmanager_command: PacManagerCommandThe command that should be executed
internal_config: InternalConfigThe “internal” configuration
non_interactive: boolSets a “non interactive” flag when possible, this prevents confirmation prompts and other things that require manual interaction
custom_flags: Option<Vec<String>>Custom flags which should be passed to the package manager